@@ -1837,6 +1837,508 @@ ags_sfz_sample_unset_flags(AgsSFZSample *sfz_sample, guint flags)
   g_rec_mutex_unlock(sfz_sample_mutex);
 }
 
+/**
+ * ags_sfz_sample_get_key:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get key of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+gint
+ags_sfz_sample_get_key(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+  
+  gint midi_key;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  midi_key = 60;
+
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "key");
+
+  if(group_key != NULL){
+    glong current_midi_key;
+    int retval;
+    
+    retval = sscanf(group_key, "%l", &current_midi_key);
+
+    if(retval > 0){
+      midi_key = current_midi_key;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_midi_key);
+
+      if(retval > 0){
+	midi_key = current_midi_key;
+      }
+    }
+
+    g_free(group_key);
+  }
+  
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "key");
+  
+  if(region_key != NULL){
+    glong current_midi_key;
+    int retval;
+
+    retval = sscanf(region_key, "%l", &current_midi_key);
+
+    if(retval <= 0){
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_midi_key);
+
+      if(retval > 0){
+	midi_key = current_midi_key;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(midi_key);
+}
+
+/**
+ * ags_sfz_sample_get_hikey:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get high key of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+gint
+ags_sfz_sample_get_hikey(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+
+  gint hikey;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  hikey = 60;
+  
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "hikey");
+    
+  if(group_key != NULL){
+    glong current_hikey;
+    int retval;
+    
+    retval = sscanf(group_key, "%l", &current_hikey);
+
+    if(retval > 0){
+      hikey = current_hikey;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_hikey);
+
+      if(retval > 0){
+	hikey = current_hikey;
+      }
+    }
+
+    g_free(group_key);
+  }
+
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "hikey");
+  
+  if(region_key != NULL){
+    glong current_hikey;
+    int retval;
+    
+    retval = sscanf(region_key, "%l", &current_hikey);
+
+    if(retval > 0){
+      hikey = current_hikey;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_hikey);
+      
+      if(retval > 0){
+	hikey = current_hikey;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(hikey);
+}
+
+/**
+ * ags_sfz_sample_get_lokey:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get low key of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+gint
+ags_sfz_sample_get_lokey(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+
+  gint lokey;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  lokey = 60;
+  
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "lokey");
+    
+  if(group_key != NULL){
+    glong current_lokey;
+    int retval;
+    
+    retval = sscanf(group_key, "%l", &current_lokey);
+
+    if(retval > 0){
+      lokey = current_lokey;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_lokey);
+
+      if(retval > 0){
+	lokey = current_lokey;
+      }
+    }
+
+    g_free(group_key);
+  }
+
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "lokey");
+  
+  if(region_key != NULL){
+    glong current_lokey;
+    int retval;
+    
+    retval = sscanf(region_key, "%l", &current_lokey);
+
+    if(retval > 0){
+      lokey = current_lokey;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_lokey);
+      
+      if(retval > 0){
+	lokey = current_lokey;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(lokey);
+}
+
+/**
+ * ags_sfz_sample_get_pitch_keycenter:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get pitch key-center of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+gint
+ags_sfz_sample_get_pitch_keycenter(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+
+  gint pitch_keycenter;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  pitch_keycenter = 60;
+  
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "pitch_keycenter");
+    
+  if(group_key != NULL){
+    glong current_pitch_keycenter;
+    int retval;
+    
+    retval = sscanf(group_key, "%l", &current_pitch_keycenter);
+
+    if(retval > 0){
+      pitch_keycenter = current_pitch_keycenter;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_pitch_keycenter);
+
+      if(retval > 0){
+	pitch_keycenter = current_pitch_keycenter;
+      }
+    }
+
+    g_free(group_key);
+  }
+
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "pitch_keycenter");
+  
+  if(region_key != NULL){
+    glong current_pitch_keycenter;
+    int retval;
+    
+    retval = sscanf(region_key, "%l", &current_pitch_keycenter);
+
+    if(retval > 0){
+      pitch_keycenter = current_pitch_keycenter;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_pitch_keycenter);
+      
+      if(retval > 0){
+	pitch_keycenter = current_pitch_keycenter;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(pitch_keycenter);
+}
+
+/**
+ * ags_sfz_sample_get_loop_mode:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get key of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+guint
+ags_sfz_sample_get_loop_mode(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+
+  guint loop_mode;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  loop_mode = AGS_SFZ_SAMPLE_LOOP_ONE_SHOT;
+  
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "loop_mode");
+    
+  if(group_key != NULL){
+    guint current_loop_mode;
+    int retval;
+    
+    retval = sscanf(group_key, "%ul", &current_loop_mode);
+
+    if(retval > 0){
+      loop_mode = current_loop_mode;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_loop_mode);
+
+      if(retval > 0){
+	loop_mode = current_loop_mode;
+      }
+    }
+
+    g_free(group_key);
+  }
+
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "loop_mode");
+  
+  if(region_key != NULL){
+    guint current_loop_mode;
+    int retval;
+    
+    retval = sscanf(region_key, "%ul", &current_loop_mode);
+
+    if(retval > 0){
+      loop_mode = current_loop_mode;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_loop_mode);
+      
+      if(retval > 0){
+	loop_mode = current_loop_mode;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(loop_mode);
+}
+
+/**
+ * ags_sfz_sample_get_loop_start:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get key of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+guint
+ags_sfz_sample_get_loop_start(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+
+  guint loop_start;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  loop_start = 0;
+  
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "loop_start");
+    
+  if(group_key != NULL){
+    guint current_loop_start;
+    int retval;
+    
+    retval = sscanf(group_key, "%ul", &current_loop_start);
+
+    if(retval > 0){
+      loop_start = current_loop_start;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_loop_start);
+
+      if(retval > 0){
+	loop_start = current_loop_start;
+      }
+    }
+
+    g_free(group_key);
+  }
+
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "loop_start");
+  
+  if(region_key != NULL){
+    guint current_loop_start;
+    int retval;
+    
+    retval = sscanf(region_key, "%ul", &current_loop_start);
+
+    if(retval > 0){
+      loop_start = current_loop_start;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_loop_start);
+      
+      if(retval > 0){
+	loop_start = current_loop_start;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(loop_start);
+}
+
+/**
+ * ags_sfz_sample_get_loop_end:
+ * @sfz_sample: the #AgsSFZSample
+ * 
+ * Get key of @sfz_sample.
+ * 
+ * Returns: the key
+ *
+ * Since: 3.7.3
+ */
+guint
+ags_sfz_sample_get_loop_end(AgsSFZSample *sfz_sample)
+{
+  gchar *group_key, *region_key;
+
+  guint loop_end;
+  
+  if(!AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return(-1);
+  }
+
+  loop_end = 0;
+  
+  group_key = ags_sfz_group_lookup_control(sfz_sample->group,
+					   "loop_end");
+    
+  if(group_key != NULL){
+    guint current_loop_end;
+    int retval;
+    
+    retval = sscanf(group_key, "%ul", &current_loop_end);
+
+    if(retval > 0){
+      loop_end = current_loop_end;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(group_key,
+						   &current_loop_end);
+
+      if(retval > 0){
+	loop_end = current_loop_end;
+      }
+    }
+
+    g_free(group_key);
+  }
+
+  region_key = ags_sfz_region_lookup_control(sfz_sample->region,
+					     "loop_end");
+  
+  if(region_key != NULL){
+    guint current_loop_end;
+    int retval;
+    
+    retval = sscanf(region_key, "%ul", &current_loop_end);
+
+    if(retval > 0){
+      loop_end = current_loop_end;
+    }else{
+      retval = ags_diatonic_scale_note_to_midi_key(region_key,
+						   &current_loop_end);
+      
+      if(retval > 0){
+	loop_end = current_loop_end;
+      }
+    }
+
+    g_free(region_key);
+  }
+
+  return(loop_end);
+}
+
 /**
  * ags_sfz_sample_new:
  *
